import aioredis


class Redis:
    def __init__(self, **kwargs):
        self.host = kwargs.get('host') or 'localhost'
        self.port = kwargs.get('port') or 6379
        self.password = kwargs.get('password')
        self.db = kwargs.get('db') or 1
        self.pool_size = kwargs.get('pool_size') or 10
        self.user = kwargs.get('user')

    async def get_redis(self, pool_size=None):
        if pool_size and isinstance(pool_size, int):
            self.pool_size = pool_size
        pool = aioredis.ConnectionPool.from_url(f"redis://{self.host}", port=int(self.port), username=self.user, password=self.password,
                                                db=int(self.db), max_connections=int(self.pool_size))
        redis = aioredis.Redis(connection_pool=pool)
        return redis


__all__ = Redis



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="hscan",
    version="1.0.6",
    author="jyanghe",
    author_email="jyanghe1023@gmail.com",
    description="A python framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jyangHe/hscan",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8.11',
)